runleiden
================

Wrapper over `leidenalg`.

## Install

```bash
poetry install
poetry shell # activate virtualenv
```

## Run Script

```bash
runleiden -i input_edgelist.txt -r resolution_value -o output_communities.txt
```